@@ -367,7 +367,7 @@ calc_all(costs,amounts,taxes,Ncivs,Nuws,bars,Nbars,mil,cap,ships,sbuild,nsbuild,
 							  Ncivs,Nuws,
 							  bars,Nbars,
 							  mil,
-							  cap,z);
+							  cap,bp,z);
 						break;
 				}
 	}
